==> mgb-0.5.4-de.zip: mgb-0.5.4-de/passwort.php <==
<?
// DO NOT REMOVE THIS COPYRIGHT //
//
// MGB v.null.fuenf (0.5.4) (C) by Jrgen Grneisl
// Visit me on http://www.tv-kritik.net/mgb/index.php
//
// This Guestbook is licensed under GNU GPL. Feel free to use, copy, share or modify it. :)

         include "settings.php";
         include "language/lang_admin.php";

         $pass=md5($_POST[pass]);
         $passwort=$settings['passwort'];

         if($_POST[erstellen]==1)
         	{
                 $pass=md5($_POST[pass]);
         	$passwort=$pass;

                 $sql="UPDATE `$db[settings]` SET `passwort` = '".$pass."' WHERE settings='1' LIMIT 1";
	        $link=mysql_connect($db[host], $db[user], $db[password]) or die ("Keine Verbindung zur Datenbank mglich. Prfen Sie die Zugangsdaten.");
         	mysql_select_db($db[dbname], $link) or die ("Datenbankfehler");
         	$result=mysql_query($sql, $link) or die ("MySQL Fehler");
                 }

         if($passwort=="")
         	{
                 $ausgabe.="<br>\n";
                 $ausgabe.="<br>\n";
                 $ausgabe.="<center>\n";
                 $ausgabe.="<form method='post' action='".$PHP_SELF."'>";
                 $ausgabe.="<table summary='passworteingabe' class='passwortfirst' cellspacing='0' cellpadding='5'>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td class='passworteingabetitel' style='height:20px'><font class='passworteingabetitel'>".$lang['createpassword_title']."</font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td class='passworteingabe'>\n";
                 $ausgabe.="<center>\n";
                 $ausgabe.="<div align='justify'><font class='passwort'>".$lang['createpassword_firstcall']."</font></div><br>";
                 $ausgabe.="<input type='password' name='pass'>\n";
                 $ausgabe.="<input type='hidden' name='erstellen' value='1'>\n";
                 $ausgabe.="</center><br>\n";
                 $ausgabe.="</td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="</table>\n";
                 $ausgabe.="<br>\n";
                 $ausgabe.="<br>\n";
                 $ausgabe.="<input class='passwort' type='submit' value='OK'>\n";
                 $ausgabe.="</form>\n";
                 $ausgabe.="<font class='passwort'><a href='guestbook.php'>".$lang['back_to_gb']."</a></font></center>\n";
                 }
         else
         	{
         	if($pass!=$passwort)
			{
                         if($fehler>=$settings['adminalerttries'])
                         	{
                                 $nachricht="<center>\n<font class='passwort_fehler'><b>".$lang['adminfailure']."</b></font>\n</center><br>\n";
                                 $ausgabe.="<br>\n";
                                 $ausgabe.="<br>\n";
                                 $ausgabe.="<center>\n";
                                 $ausgabe.="<form method='post' action='".$PHP_SELF."'>";
                                 $ausgabe.="<table summary='passworteingabe' cellspacing='0' cellpadding='2' class='passwort'>\n";
                         	$ausgabe.="<tr>\n";
         			$ausgabe.="<td class='passworteingabetitel' style='height:20px'><font class='passworteingabetitel'>".$lang['password'].":</font></td>\n";
                         	$ausgabe.="</tr>\n";
                         	$ausgabe.="<tr>\n";
         			$ausgabe.="<td class='passworteingabe'>\n";
                                 $ausgabe.="<center>\n";
                                 $ausgabe.="<input type='password' name='pass'>\n";
                                 $ausgabe.="<input type='hidden' name='fehler' value='".$fehler."'>\n";
                                 $ausgabe.="<input type='hidden' name='sent' value='1'>\n";
                                 $ausgabe.="</center>\n";
                                 $ausgabe.="</td>\n";
                         	$ausgabe.="</tr>\n";
                                 $ausgabe.="</table>\n";
                                 $ausgabe.="<br>\n";
                                 $ausgabe.="<br>\n";
                                 $ausgabe.="<input class='passwort' type='submit' value='OK'>\n";
                                 $ausgabe.="</form>\n";
                                 $ausgabe.="</center>\n";
                                 if($settings['adminalert']=="1"){$ausgabe.=$nachricht;}
                                 $zeit=date("H".":"."i");
                                 $datum=date("d"."/"."m"."/"."Y");
                                 $ip=$_SERVER["REMOTE_ADDR"];
                                 if($settings['adminalert']=="1"){mail($settings['adminemail'], $lang['password_mail_title'], $lang['password_mail_message']."\n\n".$lang['password_mail_date'].": ".$datum."\n".$lang['password_mail_time'].": ".$zeit.": ".$lang['password_mail_time_des']."\nIP: ".$ip."\n".$lang['password_mail_givenpw'].": ".$_POST[pass], "from: mgb@".$settings['hpname']);} // Mail an den Eigent&uuml;mer des G&auml;stebuches
                                 }
                         else
                         	{
                                 $fehler++;
                                 if($_POST[sent]==1){$nachricht="<center>\n<font class='passwort_fehler'><b>".$lang['wrong_password']."</b></font>\n</center><br>\n";}else{$nachricht="";}
                                 $ausgabe="<br>\n";
                                 $ausgabe.="<br>\n";
                                 $ausgabe.="<center>\n";
                                 $ausgabe.="<form method='post' action='".$PHP_SELF."'>";
                                 $ausgabe.="<table summary='passworteingabe' cellspacing='0' cellpadding='2' class='passwort'>\n";
                         	$ausgabe.="<tr>\n";
         			$ausgabe.="<td class='passworteingabetitel' style='height:20px'><font class='passworteingabetitel'>".$lang['password'].":</font></td>\n";
                         	$ausgabe.="</tr>\n";
                         	$ausgabe.="<tr>\n";
         			$ausgabe.="<td class='passworteingabe'>\n";
                                 $ausgabe.="<center>\n";
                                 $ausgabe.="<input type='password' name='pass' value='".$_COOKIE[mgb_pass]."'>\n";
                                 $ausgabe.="<input type='hidden' name='fehler' value='".$fehler."'>\n";
                                 $ausgabe.="<input type='hidden' name='sent' value='1'>\n";
                                 $ausgabe.="</center>\n";
                                 $ausgabe.="</td>\n";
                         	$ausgabe.="</tr>\n";
                                 $ausgabe.="</table>\n";
                                 $ausgabe.="<br>\n";
                                 $ausgabe.="<br>\n";
                                 $ausgabe.="<input type='submit' value='OK'>\n";
                                 $ausgabe.="</form>\n";
                                 $ausgabe.="</center>\n";
                                 $ausgabe.=$nachricht;
                                 }
                         $ausgabe.="<center>\n<font class='passwort'><a href='guestbook.php'>".$lang['back_to_gb']."</a></font></center>\n";
			}
		else
			{
                         $sid=$settings['passwort'];
                         setcookie("mgb_pass",$_POST[pass],time()+60*60*24*30);
                         $refresh="<meta http-equiv='refresh' content='1; URL=admin.php?sid=".$sid."'>";
                         $ausgabe="<center><br><br><br><br><font style='font-family:verdana; color:#000000; font-size:11px'><b>".$lang['wait']."</b></font></center>";
         		}
         	}
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title>Administration / Passworteingabe - guestbook v.null.f&uuml;nf by mopzz.de</title>
<meta name="author" content="mopzz">
<meta name="keywords" content="mgb.v.null.fuenf, mopzz.de, kostenloses g&auml;stebuch, kostenloses php g&auml;stebuch">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta name="description" content="MGB 0.5.4  Copyright 2006 by mopzz -- http://www.tv-kritik.net/mgb/index.php">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta http-equiv="content-type" content="text/html; charset=ISO-8859-1">
<link rel="stylesheet" type="text/css" href="css/admin.css">
<?php echo $refresh; ?>
</head>
<body>
<?php
	echo $ausgabe;
         include "copyright.php";
?>
</body>
</html>

==> mgb-0.5.4.3-de.zip: mgb-0.5.4.3-de/passwort.php <==
<?
	/*
	MGB 0.5.4.3
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

         include "settings.php";
         include "language/lang_admin.php";

         $pass=md5($_POST[pass]);
         $passwort=$settings['passwort'];

         if($_POST[erstellen]==1)
         	{
                 $pass=md5($_POST[pass]);
         	$passwort=$pass;

                 $sql="UPDATE `$db[settings]` SET `passwort` = '".$pass."' WHERE settings='1' LIMIT 1";
	        $link=mysql_connect($db[host], $db[user], $db[password]) or die ("Keine Verbindung zur Datenbank mglich. Prfen Sie die Zugangsdaten.");
         	mysql_select_db($db[dbname], $link) or die ("Datenbankfehler");
         	$result=mysql_query($sql, $link) or die ("MySQL Fehler");
                 }

         if($passwort=="")
         	{
                 $ausgabe.="<br>\n";
                 $ausgabe.="<br>\n";
                 $ausgabe.="<center>\n";
                 $ausgabe.="<form method='post' action='".$PHP_SELF."'>";
                 $ausgabe.="<table summary='passworteingabe' class='passwortfirst' cellspacing='0' cellpadding='5'>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td class='passworteingabetitel' style='height:20px'><font class='passworteingabetitel'>".$lang['createpassword_title']."</font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td class='passworteingabe'>\n";
                 $ausgabe.="<center>\n";
                 $ausgabe.="<div align='justify'><font class='passwort'>".$lang['createpassword_firstcall']."</font></div><br>";
                 $ausgabe.="<input type='password' name='pass'>\n";
                 $ausgabe.="<input type='hidden' name='erstellen' value='1'>\n";
                 $ausgabe.="</center><br>\n";
                 $ausgabe.="</td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="</table>\n";
                 $ausgabe.="<br>\n";
                 $ausgabe.="<br>\n";
                 $ausgabe.="<input class='passwort' type='submit' value='OK'>\n";
                 $ausgabe.="</form>\n";
                 $ausgabe.="<font class='passwort'><a href='guestbook.php'>".$lang['back_to_gb']."</a></font></center>\n";
                 }
         else
         	{
         	if($pass!=$passwort)
			{
                         if($fehler>=$settings['adminalerttries'])
                         	{
                                 $nachricht="<center>\n<font class='passwort_fehler'><b>".$lang['adminfailure']."</b></font>\n</center><br>\n";
                                 $ausgabe.="<br>\n";
                                 $ausgabe.="<br>\n";
                                 $ausgabe.="<center>\n";
                                 $ausgabe.="<form method='post' action='".$PHP_SELF."'>";
                                 $ausgabe.="<table summary='passworteingabe' cellspacing='0' cellpadding='2' class='passwort'>\n";
                         	$ausgabe.="<tr>\n";
         			$ausgabe.="<td class='passworteingabetitel' style='height:20px'><font class='passworteingabetitel'>".$lang['password'].":</font></td>\n";
                         	$ausgabe.="</tr>\n";
                         	$ausgabe.="<tr>\n";
         			$ausgabe.="<td class='passworteingabe'>\n";
                                 $ausgabe.="<center>\n";
                                 $ausgabe.="<input type='password' name='pass'>\n";
                                 $ausgabe.="<input type='hidden' name='fehler' value='".$fehler."'>\n";
                                 $ausgabe.="<input type='hidden' name='sent' value='1'>\n";
                                 $ausgabe.="</center>\n";
                                 $ausgabe.="</td>\n";
                         	$ausgabe.="</tr>\n";
                                 $ausgabe.="</table>\n";
                                 $ausgabe.="<br>\n";
                                 $ausgabe.="<br>\n";
                                 $ausgabe.="<input class='passwort' type='submit' value='OK'>\n";
                                 $ausgabe.="</form>\n";
                                 $ausgabe.="</center>\n";
                                 if($settings['adminalert']=="1"){$ausgabe.=$nachricht;}
                                 $zeit=date("H".":"."i");
                                 $datum=date("d"."/"."m"."/"."Y");
                                 $ip=$_SERVER["REMOTE_ADDR"];
                                 if($settings['adminalert']=="1"){mail($settings['adminemail'], $lang['password_mail_title'], $lang['password_mail_message']."\n\n".$lang['password_mail_date'].": ".$datum."\n".$lang['password_mail_time'].": ".$zeit.": ".$lang['password_mail_time_des']."\nIP: ".$ip."\n".$lang['password_mail_givenpw'].": ".$_POST[pass], "from: mgb@".$settings['hpname']);} // Mail an den Eigent&uuml;mer des G&auml;stebuches
                                 }
                         else
                         	{
                                 $fehler++;
                                 if($_POST[sent]==1){$nachricht="<center>\n<font class='passwort_fehler'><b>".$lang['wrong_password']."</b></font>\n</center><br>\n";}else{$nachricht="";}
                                 $ausgabe="<br>\n";
                                 $ausgabe.="<br>\n";
                                 $ausgabe.="<center>\n";
                                 $ausgabe.="<form method='post' action='".$PHP_SELF."'>";
                                 $ausgabe.="<table summary='passworteingabe' cellspacing='0' cellpadding='2' class='passwort'>\n";
                         	$ausgabe.="<tr>\n";
         			$ausgabe.="<td class='passworteingabetitel' style='height:20px'><font class='passworteingabetitel'>".$lang['password'].":</font></td>\n";
                         	$ausgabe.="</tr>\n";
                         	$ausgabe.="<tr>\n";
         			$ausgabe.="<td class='passworteingabe'>\n";
                                 $ausgabe.="<center>\n";
                                 $ausgabe.="<input type='password' name='pass' value='".$_COOKIE[mgb_pass]."'>\n";
                                 $ausgabe.="<input type='hidden' name='fehler' value='".$fehler."'>\n";
                                 $ausgabe.="<input type='hidden' name='sent' value='1'>\n";
                                 $ausgabe.="</center>\n";
                                 $ausgabe.="</td>\n";
                         	$ausgabe.="</tr>\n";
                                 $ausgabe.="</table>\n";
                                 $ausgabe.="<br>\n";
                                 $ausgabe.="<br>\n";
                                 $ausgabe.="<input type='submit' value='OK'>\n";
                                 $ausgabe.="</form>\n";
                                 $ausgabe.="</center>\n";
                                 $ausgabe.=$nachricht;
                                 }
                         $ausgabe.="<center>\n<font class='passwort'><a href='guestbook.php'>".$lang['back_to_gb']."</a></font></center>\n";
			}
		else
			{
                         $sid=$settings['passwort'];
                         setcookie("mgb_pass",$_POST[pass],time()+60*60*24*30);
                         $refresh="<meta http-equiv='refresh' content='1; URL=admin.php?sid=".$sid."'>";
                         $ausgabe="<center><br><br><br><br><font style='font-family:verdana; color:#000000; font-size:11px'><b>".$lang['wait']."</b></font></center>";
         		}
         	}
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title>Administration / Passworteingabe - guestbook v.null.f&uuml;nf by mopzz.de</title>
<meta name="author" content="mopzz">
<meta name="keywords" content="mgb.v.null.fuenf, mopzz.de, kostenloses g&auml;stebuch, kostenloses php g&auml;stebuch">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta name="description" content="MGB 0.5.4.3  Copyright 2006 by mopzz -- http://www.tv-kritik.net/mgb/index.php">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta http-equiv="content-type" content="text/html; charset=ISO-8859-1">
<link rel="stylesheet" type="text/css" href="css/admin.css">
<?php echo $refresh; ?>
</head>
<body>
<?php
	echo $ausgabe;
         include "copyright.php";
?>
</body>
</html>
